@@ -8,7 +8,6 @@ use GraphQL::Type::Library -all;
 use GraphQL::Debug qw(_debug);
 use Types::Standard -all;
 use JSON::MaybeXS qw(JSON is_bool);
-use DateTime::Format::ISO8601;
 use Exporter 'import';
 extends qw(GraphQL::Type);
 with qw(
@@ -17,13 +16,14 @@ with qw(
   GraphQL::Role::Leaf
   GraphQL::Role::Nullable
   GraphQL::Role::Named
+  GraphQL::Role::FieldsEither
 );
 use Function::Parameters;
 use Return::Type;
-use GraphQL::Debug qw(_debug);
+use GraphQL::Plugin::Type;
 
 our $VERSION = '0.02';
-our @EXPORT_OK = qw($Int $Float $String $Boolean $ID $DateTime);
+our @EXPORT_OK = qw($Int $Float $String $Boolean $ID);
 
 use constant DEBUG => $ENV{GRAPHQL_DEBUG};
 my $JSON = JSON::MaybeXS->new->allow_nonref->canonical;
@@ -116,7 +116,7 @@ sub _build_to_doc {
   my ($self) = @_;
   DEBUG and _debug('Scalar.to_doc', $self);
   join '', map "$_\n",
-    ($self->description ? (map "# $_", split /\n/, $self->description) : ()),
+    $self->_description_doc_lines($self->description),
     "scalar @{[$self->name]}";
 }
 
@@ -197,20 +197,7 @@ our $ID = GraphQL::Type::Scalar->new(
   parse_value => sub { defined $_[0] and Str->(@_); $_[0] },
 );
 
-=head2 $DateTime
-
-=cut
-
-my $iso8601 = DateTime::Format::ISO8601->new;
-our $DateTime = GraphQL::Type::Scalar->new(
-  name => 'DateTime',
-  description =>
-    'The `DateTime` scalar type represents a point in time. ' .
-    'Canonically represented using ISO 8601 format, e.g. 20171114T07:41:10, ' .
-    'which is 14 November 2017 at 07:41am.',
-  serialize => sub { return if !defined $_[0]; $_[0].'' },
-  parse_value => sub { return if !defined $_[0]; $iso8601->parse_datetime(@_); },
-);
+GraphQL::Plugin::Type->register($_) for ($Int, $Float, $String, $Boolean, $ID);
 
 __PACKAGE__->meta->make_immutable();
 
